--------------------------------------------------------------------------------------------------------------
-- TITLE           :   SQL components used to test DAO execution of the "Template WS" project.
-- LAST MODIFIED   :   25/04/2012
-- AUTHOR          :   S. ADRIANI
-- VERSION         :   1.0
-- REFERENCE       :   Adriani's Oracle Project (AOP): a tutorial for building a JSP-Oracle benchmark
--                 :   (Personal remark: consider this SQL code as branch of the AOP's trunk)
-- TO DO           :   Nothing
--------------------------------------------------------------------------------------------------------------

--------------------------------------------------------------------------------------------------------------
-- 1. CREATING A VERY SIMPLE TABLE, WITHOUT ANY CONSTRAINT
-- Example: this table could store execution times of detailed code blocks, referred as "entities"
-- An entity could be: a single http GET request, a single Ajax call, a single SQL query etc.
--------------------------------------------------------------------------------------------------------------

CREATE TABLE "SCOTT"."ENTITY_TIMES" 
(
"ID_ENTITY" NUMBER(11,0) NOT NULL ENABLE, 
"LABEL" VARCHAR2(500 BYTE) NOT NULL ENABLE, 
"START_TIME" TIMESTAMP (4), 
"END_TIME" TIMESTAMP (4)
) ;
-- 1.1 Creating the index for this table
CREATE INDEX "SCOTT"."ENTITY_TIMES_INDEX" ON "SCOTT"."ENTITY_TIMES" (TRUNC("START_TIME")) ;

--------------------------------------------------------------------------------------------------------------
-- 2. CREATING ANOTHER VERY SIMPLE TABLE, WITH A PRIMARY KEY
--------------------------------------------------------------------------------------------------------------

CREATE TABLE "SCOTT"."CUSTOMERS" (
  "CUSTOMER_ID" NUMBER(11,0) NOT NULL ENABLE, 
  "NAME" VARCHAR2(20 BYTE), 
  "SURNAME" VARCHAR2(20 BYTE), 
  "COMPANY" VARCHAR2(30 BYTE), 
  "ADDRESS" VARCHAR2(30 BYTE), 
  "TOWN" VARCHAR2(20 BYTE), 
  "COUNTRY" VARCHAR2(20 BYTE), 
  "TELEPHONE" VARCHAR2(20 BYTE), 
  CONSTRAINT "CUSTOMERS_TBL_PK" PRIMARY KEY ("CUSTOMER_ID")
) ;

--------------------------------------------------------------------------------------------------------------
-- 3. SAMPLE DATA FOR THE ENTITY_TIMES TABLE
--------------------------------------------------------------------------------------------------------------

INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (1 , 'A dummy http get request', '10-APR-2012 11:00:00', '10-APR-2012 11:00:01') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (2 , 'A dummy http ajax request', '10-APR-2012 12:00:00', '10-APR-2012 12:00:02') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (3 , 'A dummy SQL query', '10-APR-2012 13:00:00', '10-APR-2012 13:00:03') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (4 , 'A general entity' , '10-APR-2012 13:01:00', '10-APR-2012 13:01:03') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (5 , 'Benchmark_query_1', '10-APR-2012 13:02:00', '10-APR-2012 13:02:04') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (6 , 'Benchmark_query_1', '10-APR-2012 13:03:00', '10-APR-2012 13:03:02') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (7 , 'Benchmark_query_1', '10-APR-2012 13:04:00', '10-APR-2012 13:04:02') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (8 , 'Benchmark_query_1', '10-APR-2012 13:05:00', '10-APR-2012 13:05:05') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (9 , 'Benchmark_query_1', '10-APR-2012 13:06:00', '10-APR-2012 13:06:01') ;
INSERT INTO ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (10, 'Benchmark_query_1', '10-APR-2012 13:07:00', '10-APR-2012 13:07:02') ;

--------------------------------------------------------------------------------------------------------------
-- 4. SAMPLE DATA FOR THE CUSTOMERS TABLE
--------------------------------------------------------------------------------------------------------------

INSERT INTO CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (1, 'Stefano', 'Adriani', 'Italy', '0498978842') ;
INSERT INTO CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (2, 'Steve'  , 'Goonie' , 'United Kingdom','010202404') ;
INSERT INTO CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (3, 'Jousha' , 'Tree'   , 'Ireland', '0431999536') ;

/*
--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: CHECK INDEX/CONSTRAINTS STATUS (just to verify the create procedure)
--------------------------------------------------------------------------------------------------------------

-- We should have 2 indexes
SELECT index_name, table_name, uniqueness, funcidx_status FROM user_indexes 
WHERE table_name = 'ENTITY_TIMES' 
OR table_name = 'CUSTOMERS'
;

-- We should have 1 constraint
SELECT constraint_name, status FROM user_constraints 
WHERE constraint_name NOT LIKE 'SYS%'
AND (
table_name = 'ENTITY_TIMES' 
OR table_name = 'CUSTOMERS'
) ;

-- Disabling/Enabling foreign keys
ALTER TABLE CUSTOMERS ENABLE CONSTRAINT CUSTOMERS_TBL_PK;
ALTER TABLE CUSTOMERS DISABLE CONSTRAINT CUSTOMERS_TBL_PK;
 */