--------------------------------------------------------------------------------------------------------------
-- TITLE           :   SQL components used to test DAO execution of the "Template WS" project.
-- LAST MODIFIED   :   25/04/2012
-- AUTHOR          :   S. ADRIANI
-- VERSION         :   1.0
-- REFERENCE       :   Adriani's Oracle Project (AOP): a tutorial for building a JSP-Oracle benchmark
--                 :   (Personal remark: consider this SQL code as branch of the AOP's trunk)
-- TO DO           :   Nothing
--------------------------------------------------------------------------------------------------------------

CREATE OR REPLACE PROCEDURE VERIFY_ENTITY_ID(entity_id IN NUMBER, entity_label IN OUT VARCHAR2)
AS
--------------------------------------------------------------------------------------------------------------
-- FUNCTION            :   VERIFY_ENTITY_ID
-- LAST MODIFIED       :   25/04/2012
-- AUTHOR              :   S. ADRIANI
-- DESCRIPTION         :   Return the label for the input entity ID (for this usage entity_label should be '0'
--                     :   or NULL. The procedure allows to force the result passing as input a not null
--                     :   label: in such case the input label is returned istead of the right one.

-- INPUT PARAMETERS
-- entity_id           :   The ID of the entity (an integer number)
-- entity_label        :   The label of the entity, e.g. "Benchmark_query_1"

-- OUTPUT PARAMETERS   :   

-- REMARK              :   The result of this procedure could be obtained by a simple "old plain SQL query":
--                     :   here we used a procedure just to show some basic PL/SQL features
--------------------------------------------------------------------------------------------------------------

  -- Debug variables
  verbose           BOOLEAN := TRUE ;
  error_code		VARCHAR2(12) ;
  error_message		VARCHAR2(300) ;

BEGIN
    
  IF ( (entity_label = '0') OR (entity_label IS NULL) ) THEN
    
    BEGIN
    
      SELECT et.label INTO entity_label FROM entity_times et
      WHERE et.id_entity = entity_id
      AND ROWNUM < 2 ;
    
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
      error_code    := SQLCODE ;
      error_message :='Error in VERIFY_ENTITY_ID on input: '||entity_label||' - '||entity_id||' - '||'The entity has not id code' ;
      DBMS_OUTPUT.PUT_LINE('[PUBLIC_PACKAGE] - VERIFY_ENTITY_ID'||ora_sysevent||error_code||error_message) ;
      entity_label  := NULL ;
            
    END ;
	
  END IF ;
  
END VERIFY_ENTITY_ID ;

/*
--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: SQL STATEMENT FOR TESTING/DEBUG ON A SQL CLIENT
--------------------------------------------------------------------------------------------------------------

SET SERVEROUTPUT ON;
EXEC DBMS_OUTPUT.ENABLE(1000000);

DECLARE
  ENTITY_ID NUMBER;
  ENTITY_LABEL VARCHAR2(200);
BEGIN
  ENTITY_ID := 4;
  ENTITY_LABEL := NULL;

  VERIFY_ENTITY_ID(
    ENTITY_ID => ENTITY_ID,
    ENTITY_LABEL => ENTITY_LABEL
  );
  DBMS_OUTPUT.PUT_LINE('ENTITY_LABEL = ' || ENTITY_LABEL);
END;
*/