/**
* Title: 		Settings
* Description:	Static wrapper for the global static configuration
* Copyright:    Copyright (c) 2003-2012
* Company:      Morpheus Quality Technologies
* @author 		Stefano Adriani
* @version 		1.1
*/

package adriani.jws.template ;

import java.util.ResourceBundle;
import java.util.MissingResourceException;

/**
* Class containing the static values defining boolean flags, constants and logical names.
*/
public class Settings {

	/** Version of this project.																		*/
	public static String	VERSION		= "1.1" ;

	/** If <code>true</code> debug messages are printed on standard output.								*/
	public static boolean	DEBUG		= true ;						// Default value

	/** If <code>true</code> very detailed debug messages are printed on the standard output (verbose).	*/
	public static boolean	VERBOSE		= true ;						// Default value

	/** If <code>true</code> statistical analysis data are collected during execution.					*/
	public static boolean	ANALYZE		= false ;						// Default value

	/** If <code>true</code> the remote manager mechanism is active.									*/
	public static boolean	MANAGER		= true ;						// Default value

	/** If <code>true</code> the benchmark log file will be created in the <code>LOGDIR</code> folder.	*/
	public static boolean	BENCH		= false ;						// Default value

// ******************************************************************************************************
// **************************				LOGGER TYPES					*****************************
// ******************************************************************************************************

  	/** If <code>true</code> the web service is configured to use the Log4j mechanism.					*/
	public static boolean 	LOG4J		= false ;						// Default value

  	/** If <code>true</code> the web service is configured to use the <code>SystemLogger</code> logger.	*/
	public static boolean 	JAVA		= true ;						// Default value

// ******************************************************************************************************
// **************************				LOG4J SETTINGS					*****************************
// ******************************************************************************************************

	/** Name of the web service, used to build other logical names.										*/
	public static String	SERVICE		= "template" ;					// Default value

	/** Name of the logger used by Log4j for the logical class group.									*/
	public static String	LOGIC		= SERVICE + ".logic" ;			// Default value

	/** Name of the logger used by Log4j for the DAO class group.										*/
	public static String	DBA			= SERVICE + ".dao" ;			// Default value

	/** File name of the Log4j configuration file (extension is "properties").							*/
	public static String	LOG_CONFIG	= "adriani.jws.template.resources.log4j_" + SERVICE ;

// ******************************************************************************************************
// **************************			SYSTEM LOGGER SETTINGS				*****************************
// ******************************************************************************************************

	/** Parent directory for the log files (only when using the <code>SystemLogger</code> class).		*/
	public static String	LOGDIR		= "logs" ;						// Default value

	/** Logic name of the logger object (only when using the <code>SystemLogger</code> class).			*/
	public static String	LOGGER		= SERVICE + ".logger" ;			// Logic name

	/** Name of the performance analyzer object (only when using the <code>SystemLogger</code> class).	*/
	public static String	BENCHMARK 	= SERVICE + ".benchmark" ;		// Logic name

	/** Rotation of the logger file (minutes) (only when using the <code>SystemLogger</code> class).	*/
	public static int		ROTATE 		= 480 ;							// Default value

	/** Name of the possible extensions to be parsed by the <code>SystemLogger</code> (if used).		*/
	public static String[]	ARCHIVE 	= {".class", ".jar", ".aar"} ;

// ******************************************************************************************************
// **************************				PROPERTIES						*****************************
// ******************************************************************************************************

	/** File name of the configuration Resource Bundle (extension is "properties").						*/
	public static String	CONFIG		= "adriani.jws.template.resources.configuration"  ;

	/** File name of the message list Resource Bundle (extension is "properties").						*/
	public static String	MESSAGES	= "adriani.jws.template.resources.messages_list" ;

	/** File name of the logic keywords Resource Bundle (extension is "properties").					*/
	public static String	KEYWORDS	= "adriani.jws.template.resources.keywords" ;

// ******************************************************************************************************
// **************************			   RESOURCE BUNDLE					*****************************
// ******************************************************************************************************

	static {
		// Loading logical flags from the properties file (defined above)
		try {
			ResourceBundle rb	= ResourceBundle.getBundle(CONFIG) ;
			//System.out.println("Setting static code-block: loaded bundle: " + CONFIG) ;

			// Retrieving string properties
			String NAME			= rb.getString("service.name") ;

			// Setting static values
			Settings.SERVICE 	= new String(NAME) ;
			Settings.LOGIC		= NAME + ".logic" ;
			Settings.DBA		= NAME + ".dao" ;
			Settings.LOGGER		= NAME + ".logger" ;
			Settings.BENCHMARK 	= NAME + ".benchmark" ;
			Settings.LOG_CONFIG	= "adriani.jws.template.resources.log4j_" + NAME ;			

		} catch(MissingResourceException e) {
			System.err.println("Settings - Configuration file not found: using defaults") ;
			e.printStackTrace() ;
		}
	}

} // End of class