/**
* Title: 		Library
* Description: 	Testing Java enumeration type
* Copyright:    Copyright (c) 2008-2012
* Company:      Morpheus Quality Technologies
* @author 		Stefano Adriani
* @version 		1.0
*/

package adriani.jws.template.client ;

/** Class-like definition.<br/><br/>
*
* Usage: <code>Java adriani.jws.template.client.Library</code>.<br/><br/>
*
* The advantage to use the <code>enum</code> type, compared to basic Java sets, is the possibility to add
* inner methods to the enumeration, even a <code>main()</code> method!<br/>
* In other words, the <code>enum</code> type is a wrapper for static collections, offering a smart syntax
* allowing to save coding time (e.g. easy definitions of LABELS and related CONSTANTS values).
*/
public enum Library {

	/** Enum definition (MANDATORY).																		*/
	ROOT		(1, 3.686e3)	,
	CLIENT		(4, 53.996e3)	,
	DB			(7, 102.925e3)	,
	ECLIPSE		(11, 186.533e3)	,
	MESSAGGES	(7, 39.131e3)	,
	RESOURCES	(12, 19.927e3)	,
	SERVICE		(7, 74.485e3)	,
	UTIL		(7, 55.771e3)	;

	/** Number of classes in the package.																	*/
	private final 		int 	howMany ;

	/** Size in bytes. 																						*/
	private final 		double 	size ;

	/** Constructor. 																						*/
	Library(int n, double s) {

		this.howMany 	= n ;
		this.size 		= s ;
	}

// ************************************************************************************************************
// **********************************			ENUM METHODS			***************************************
// ************************************************************************************************************

	/** Accessor. 																							*/
	private int number() 							{			return howMany ; 							}

	/** Accessor. 																							*/
	private double size() 							{ 			return size ;	 							}

	/** Conversion utility.																					*/
	private String getKiloBytes() 					{          	return getKiloBytes(size) ;					}

	/** Conversion utility.																					*/
	private String getKiloBytes(double value) {

		String label = new String("" + value/1024) ;
		int index = label.indexOf('.') ;
		if (index > 0) label = label.substring(0, index + 2) + " KB" ;
		return label ;
	}

	/** Formatter utility.																					*/
	private String getFormattedData() {

		String blanks = "" ;
		int max = 10 - name().length() ;
		for (int i = 0 ; i < max ; i++) blanks += " " ;
		String output = blanks + " = " + getKiloBytes() + "   (" + howMany + " classes)" ;
		return output ;
	}

// ************************************************************************************************************
// **********************************			MAIN METHOD 			***************************************
// ************************************************************************************************************

	/**
	* Main method.
	*/
	public static void main(String[] args) {

		// Initiliazing
		int classes = 0 ;
		double total = 0 ;

		// Looping through all enum types
		for ( Library p : Library.values() ) {
			total += p.size() ;
			classes += p.number() ;
			System.out.println("Package " + p + p.getFormattedData()) ;
		}

		// Printing result
		System.out.println() ;
		System.out.println("Package classes: " + classes) ;
		// Remark: in this case we could call the "getKiloBytes(total)" method on ANY enum types
		System.out.println("Package size: " + ROOT.getKiloBytes(total) + " (" + total + " bytes)") ;
	}

} // End of enum