/**
* Title: 		GeneralThread
* Description:	The parent class for all custom threads required by this architecture
* Copyright:    Copyright (c) 2010-2012
* Company:      Morpheus Quality Technologies
* @author 		Stefano Adriani
* @version 		1.0
*/

package adriani.jws.template.util ;

/**
* The parent class for all the <code>Thread</code> classes used by this project.
* For the time being this class is used only by the <code>RotateThread</code> class.
*/
public abstract class GeneralThread {

	/** The <code>Thread</code> wrapped by this class.														*/
	public 					Thread 				theThread ;

	/** If <code>false</code> no operation is performed during the main "run-cycle".						*/
	public 					boolean 			active ;

	/** If <code>false</code> the wrapped <code>Thread</code> exits from the endless loop and stops. 		*/
	public 					boolean 			running ;

// **********************************************************************************************************
// ********************************			MAIN CYCLE MUTATORS 		*************************************
// **********************************************************************************************************

	/**
	* Specifies if this thread must perform his duty. If set to <code>false</code> the thread continues to cycle
	* his endless loop, but does NOT execute the task within the endless loop.<br/>
	*
	* @param value if <code>false</code> no operation is performed during the main run cycle
	*/
	public void setActive(boolean value) 	{		this.active = value ;									}

	/**
	* Stop the endless <em>while</em> loop contained in the <code>run()</code> method. This will terminate
	* execution of the <code>run()</code> method.
	*/
	public void stopCycle() 				{		this.running = false ;									}

	/**
	* Specifies if this thread is ACTIVE (i.e. if it's set to perform his duty).<br/>
	*
	* @return <code>true</code> if this thread is active
	*/
	public boolean isActive() 				{		return this.active ;									}

	/**
	* Specifies if this thread is RUNNING (i.e. if it's still running the While loop). If this method
	* return <code>false</code> then the endless loop is terminated and the <code>run()</code> has finished
	* execution.<br/>
	*
	* @return <code>true</code> if this thread is running
	*/
	public boolean isRunning() 				{		return this.running ;									}

// **********************************************************************************************************
// *******************************			  WAIT & DELAY 			*****************************************
// **********************************************************************************************************

   /**
    * Stops this thread for few milliseconds.<br/>
    *
    * @param time the time (in milliseconds) that this thread must be stopped
    */
    public void delay(long time) {

		// Sleeping the current thread
		try {
			theThread.sleep(time) ;
		} catch (InterruptedException interrupted) {
		  	System.err.println(this.getClass().getName() + ": error while sleeping") ;
		  	interrupted.printStackTrace() ;
		}
		// Checking if the thread must be interrupted
		if (!running) try {
			theThread.interrupt() ;
		}
		catch (NullPointerException e) {
			System.err.println(this.getClass().getName() + " trying to stop a null thread") ;
		}
    }

} // End of class