/**
* Title: 		SoapElements
* Description:	Simple wrapper for the SOAP elements extracted from a SOAP envelope
* Copyright:    Copyright (c) 2012
* Company:      Morpheus Quality Technologies
* @author 		Stefano Adriani
* @version 		1.1
*/

package adriani.jws.template.util ;

import java.util.Iterator;

import adriani.jws.template.Settings ;
import org.apache.axiom.om.OMElement ;
//import org.apache.axiom.om.impl.traverse.OMChildrenIterator ;

/**
*
*
*/
public class SoapElements {

	/** Retrieving the logger instance to be used for this class.											*/
	protected 		 			OMElement		the_body ;

	/** Retrieving the logger instance to be used for this class.											*/
	protected 		 			OMElement		the_header ;

	/** Retrieving the logger instance to be used for this class.											*/
	protected static 			WSLogger		logger 			= WSLogger.getLogger(SoapElements.class) ;

	/** Beginning of each logging message produced by this class.											*/
	protected static final		String 			leadingName 	= "SoapElements - " ;


	/**
	*
	*
	* @param element a valid child of the <code>org.apache.axiom.om.OMElement</code> interface
	*/
	public SoapElements(OMElement element) {

		this.the_header = element ;
	}

	/**
	*
	*
	* @param header a valid child of the <code>org.apache.axiom.om.OMElement</code> interface
	* @param body a valid child of the <code>org.apache.axiom.om.OMElement</code> interface
	*/
	public SoapElements(OMElement header, OMElement body) {

		this.the_header	= header ;
		this.the_body	= body ;
	}

// ************************************************************************************************************
// **********************************			ACCESSORS				***************************************
// ************************************************************************************************************

	/**
	* Return the authentication data contained in the SOAP's header. In current implementation this should
	* be an element like:<br/><br/>
	*
	* <{https://i-maginary.com/webservices/idmc}:psk>value of the preshared key</psk><br/><br/>
	*
	* or, in short form, if a prefix "qd2" is bound to the namespace:<br/><br/>
	*
	* <psk>value of the preshared key</psk><br/><br/>
	*
	* @return a child of the <code>org.apache.axiom.om.OMElement</code> interface
	*/
	public String getHeaderData() {

		// 1. Checking header
		if (this.the_header == null) {
			logger.logSevere(leadingName + "Header missing in the SOAP request") ;
			return null ;
		}
		int			size		= 0 ;
		int 		line 		= this.the_header.getLineNumber() ;
		OMElement 	first 		= this.the_header.getFirstElement() ;
		if (first == null) {
			logger.logWarning(leadingName + "First element missing in the SOAP request") ;
			return null ;
		}
		//System.out.println(leadingName + "this.the_header = " + this.the_header) ;

		// 2. Getting first element from the header (should be the PSK)
		String		first_value	= first.getText() ;
		if (logger.isInfoEnabled()) logger.logInfo(leadingName + "parsed value: " + first_value + " (" + line +")") ;
		//System.out.println(leadingName + "first_value = " + first_value) ;

		// 3. Getting all header's elements (should be a OMChildrenIterator object)
		Iterator<OMElement> children = this.the_header.getChildren() ;
		//Iterator children_2 = this.the_header.getChildElements() ;
		//System.out.println(leadingName + "children = " + children) ;

		// 4. Counting header's elements
		while (children.hasNext()) {
			size++ ;
			OMElement child = children.next() ;
			if (Settings.VERBOSE) System.out.println(leadingName + "child = " + child) ;
			//System.out.println(leadingName + "child.qname = " + child.getQName()) ;
		}

		// 5. Logging parsing results
		switch(size) {
			case 0	: logger.logSevere	(leadingName + "Found empty header!") ;								break ;
			case 1  : logger.logInfo	(leadingName + "Retrieved exactly one element from the header") ;	break ;
			default	: logger.logWarning	(leadingName + "Too many elements in the header") ;
		}

		// Keep for testing or debug
		/*System.out.println(leadingName + "using OMContainer.getChildren()") ;
		while (children.hasNext()) {
			System.out.println(leadingName + "child = " + children.next()) ;
		}
		System.out.println(leadingName + "using OMElement.getChildElements()") ;
		while (children_2.hasNext()) {
			System.out.println(leadingName + "child = " + children_2.next()) ;
		}*/

		// 6. Returning first element
		return first_value ;
	}
	/**
	* Simple accessor method.
	*
	* @return a child of the <code>org.apache.axiom.om.OMElement</code> interface
	*/
	public OMElement getFirstElement() {

		return this.the_body.getFirstElement() ;
	}

	/**
	* Simple accessor method.
	*
	* @return a child of the <code>org.apache.axiom.om.OMElement</code> interface
	*/
	public OMElement getBody() {

		return this.the_body;
	}

	/**
	* Simple accessor method.
	*
	* @return a child of the <code>org.apache.axiom.om.OMElement</code> interface
	*/
	public OMElement getHeader() {

		return this.the_header;
	}

} // End of class