/**
* Title: 		WrapperInformation
* Description:	Atomic wrapper class for the single record in the SOAP response
* Copyright:    Copyright (c) 2009-2012
* Company:      Morpheus Quality Technologies
* @author 		Stefano Adriani
* @version 		1.1
*/

package adriani.jws.template.wrappers ;

import adriani.jws.template.* ;
import adriani.jws.template.wsdl.*;

/**
* WrapperInformation - general class wrapping the inner <code>ADBBean</code> elements containing a single
* <code>SingleRecordType</code> object.
*/
public class WrapperInformation extends Wrapper {

 	/** Static default value for the FIRST field (should match one of the static reference values).			*/
	public static final StringBuffer 		FIRST			= new StringBuffer("FIRST") ;
	/** Static default value for the FIRST field (should match one of the static reference values).			*/
	public static final StringBuffer 		SECOND			= new StringBuffer("SECOND") ;

  	/** Wrapped output value, used to fill the SOAP response during validation.								*/
	protected 			StringBuffer	 	first ;
	/** Wrapped output value, used to fill the SOAP response during validation.								*/
	protected 			StringBuffer	 	second ;

	/**
	* Stateless constructor, loading the default values into this wrapper.
	*
	* @see setDefaults()
	*/
	public WrapperInformation() {

		WrapperInformation.leadingName = "WrapperInformation - " ;		// MUST BE first line
		this.setDefaults() ;
		//System.out.println(leadingName + "Created new instance") ;
	}

// **********************************************************************************************************
// **********************************		ADBBEAN MANAGEMENT		*****************************************
// **********************************************************************************************************

	/**
	* Validation is performed by the Eclipse's <code>ADBBean</code> objects ( e.g. NameType.setNameType() ).
	* If the validation process is successful, the resulting <code>ADBBean</code> object is stored as
	* class field to save computation time, since after validation we expect that the method
	* <code>getElement()</code> should be invoked.<br/><br/>
	*
	* <strong>Remark:</strong> to grant LOOSE COUPLING to the WSDL, the <code>ADBBean</code> Java classes
	* should be used only within this method and in the <code>forceMessage()</code> method, not elsewhere.
	*
	* @return a reference to the <code>ADBBean</code> object wrapped by this class
	*/
	public boolean validate() throws WrapperFault {

		// 1. Preparing variables
		String 		msg 	= null ;

		// 2. Defining root element
		RecordsType root	= new RecordsType() ;

		// 3. Defining ADBBean types
		NameType							firstType					= new NameType() ;
		NameType							secondType					= new NameType() ;
		//System.out.println(leadingName + "Creating inner ADBBean objects with values: " + first +"-" + second) ;

		// 4.a Trying to set the class attribute into the corresponding ADBBean elements
		String value = this.first.toString() ;
		for (int i = 0 ; i < 2 ; i++) {
			try 				{	firstType.setNameType(value) ; 				break ;						}
			catch(Exception e)	{ 	value = FIRST.toString() ;					msg = "FIRST" ;				}
		}
		value = this.second.toString() ;
		for (int i = 0 ; i < 2 ; i++) {
			try 				{	secondType.setNameType(value) ; 			break ;						}
			catch(Exception e)	{ 	value = SECOND.toString() ;					msg = "SECOND" ;			}
		}
		// 4.b Example: if some fields can not throw exceptions, we just set them
		//if (this.name != null)				thirdType.setName	( this.name.toString()			) ;
		//System.out.println(leadingName + "Created all inner ADBBean objects") ;

		// 5. Setting the root main element, which can not throw exceptions
		root.setFirst( firstType ) ;
		root.setSecond( secondType ) ;

		// 5. Storing root element as class field
		this.element = (Object) root ;

		// 7. Handling errors
		if (msg == null) {
			if (Settings.VERBOSE) System.out.println(leadingName + "Wrapped a valid single record") ;
		} else {
			if (Settings.VERBOSE) System.out.println(leadingName + "Invalid single wrapper, using defaults") ;
			throw new WrapperFault(msg) ;
		}

		// 8. Returning validation result
		return (msg == null) ;
	}

	/**
	* Load all the STATIC default values (defined in this class) into the corresponding class attributes.
	* This method is called by the constructor to ensure that we "empty wrapper" contains always some
	* good default values matching the WSDL constrains.
	*
	* @see WrapperData()
	*/
	public void setDefaults() {

		setFirst(FIRST) ;
		setSecond(SECOND) ;
		if (Settings.VERBOSE) System.out.println(leadingName + "Set defaults values") ;
	}

// **********************************************************************************************************
// **********************************			ACCESSORS		*********************************************
// **********************************************************************************************************

	/**
	* Accessor method.
	*/
	public StringBuffer getFirst()					{		return this.first ;								}

	/**
	* Accessor method.
	*/
	public StringBuffer getSecond()					{		return this.second ;							}

// **********************************************************************************************************
// **********************************			MUTATORS		*********************************************
// **********************************************************************************************************

	/**
	* Mutator method.
	*/
	public void setFirst(StringBuffer value)		{		this.first = value ;							}

	/**
	* Mutator method.
	*/
	public void setSecond(StringBuffer value)		{		this.second = value ;							}

	/**
	* Mutator method (template for integer fields).
	*
	public void setThird(int value) {

		try 				{ this.third = Integer.parseInt( value.toString() ) ;							}
		catch(Exception e) 	{ this.third = NOT_AVAILABLE ;													}
		//System.out.println(leadingName + "Set third value: " + this.third) ;
	}*/

} // End of class